# Parameters in `base_vars.yml`
Parameters in `base_vars.yml` configure the common functionality of the control plane which includes information of the nics, dhcp ranges, pods cidr for k8s pod IP ranges, etc.
This file is located in [/control_plane/input_params](../../../control_plane/input_params/base_vars.yml)

|     Variables    [Required/   Optional]	  |   **Default**, Accepted values                                                                        |   Description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                	|
|---------------------------------------------|-------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------	|
| ansible_conf_file_path	[Required]        |     	**/etc/ansible**	                                                                          |        Directory path with the Ansible       configuration file (ansible.cfg). If Ansible is installed using   pip,   provide   the directory path. If the   path is not provided, it is set as   /etc/ansible,   by default.	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                	|
| device_config_support   [Required]          |   **false**, true                                                                                     |   This variable decides whether Management   IPs   are to be assigned to all   devices.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      	|
| idrac_support   [Required]			      |   **false**,   true                                                                                   |     This boolean indicates that Management IPs   are assigned and can be taken from   `device_list_path` for communication.     <br> If `device_config_support` is true, `idrac_support` has to   be set to true.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            	|
| device_ip_list_path   [Optional]            |                                                                                                       |  File Path where all pre-assigned   Management IPs are provided. <br>   This field is mandatory if     `idrac_support` is true. <br> A sample template is provided   here:     `omnia/examples/device_ip_list.yml` <br> Please ensure that all   listed IPs are reachable to the control plane via the Public internet                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       	|
| ethernet_switch_support   [Required]        |   **false**,   true                                                                                   |  This boolean decides whether Ethernet   Switches are to be configured.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      	|
| ib_switch_support   [Required]              |   **false**, true                                                                                     |  This boolean decides whether Infiniband   Switches are to be configured.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    	|
| powervault_support   [Required]             |   **false**,   true                                                                                   |  This boolean decides whether   PowerVaults   are to be   configured.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        	|
| enable_security_support   [Required]        |   **true**, false                                                                                     |   This variable decides whether FreeIPA   will   be deployed and used on the   Control Plane to control access and     authorization. For more information, [click     here](https://github.com/dellhpc/omnia/blob/devel/docs/Security/Enable_Security_ManagementStation.md)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 	|
| public_nic   [Required]                     |   	**eno2**	                                                                                      |        The NIC or Ethernet card connected to the   public internet.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          	|
| appliance_k8s_pod_net_cidr	[Required]	  |   	**192.168.0.0/16**	                                                                              |      Kubernetes pod network CIDR for   appliance   k8s network. Ensure this   value does not   overlap with any of   the host     networks.	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  	|
| snmp_trap_destination	[Optional]            |   		                                                                                              |        Enter an SNMP server IP address to receive   SNMP traps from devices in the cluster.   If   this variable is left blank, SNMP     will be disabled.	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   	|
| snmp_community_name</br>	[Required]   	  |   	**public**	                                                                                      |      SNMP community name. 	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   	|
| awx_organization	[Required]                |   	**DellEMC**	                                                                                      | Organization name configured in   AWX.	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       	|
| mount_location	[Required]		          |   **/opt/omnia/**                                                                                     |   The filepath where the grafana persistent   volume will be created. <br> When `telemetry.yml` is run, both the   `timescaledb` and the `mysqldb` are stored here.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          	|
| provision_method   [Required]               |   **PXE**, idrac                                                                                      |     This variable is used to set node provisioning method <br> If   `device_config_support` is true, **PXE** will be used. <br> __Note__ :   This parameter is case sensitive.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               	|
| provision_state [Required]                  |   **stateful**                                                                                        |   If       stateful is set, cobbler is used to provision disks. Stateless is   currently     not supported.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  	|
| provision_os   [Required]                   |   **rocky**, centos   ,   leap                                                                        |     This is the operating system image that will   be used for provisioning compute nodes in   the cluster.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  	|
| iso_file_path	[Required]	                  |     **/root/Rocky-8.x-x86_64-minimal.iso**,     <br><br>/root/openSUSE-Leap-15.3-NET-x86_64-Media.iso |      Provide the relevant ISO file path. This   ISO file is used by Cobbler   to   provision the OS on the   compute   nodes. **Note**: It is recommended that   the ISO image file is not renamed.     And, you **must not** change the path of this ISO image file as the   provisioning of the OS on the compute   nodes may be impacted.	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 	|
| timezone   [Required]	                      |   	**GMT**	                                                                                          |  Enter a timezone that is set during the   provisioning of OS. **GMT** is set as   the   default time zone. You can set   the     time zone to **EST**, **CET**,   **MST**, **CST6CDT**, or **PST8PDT**.     For a   list of available time   zones,   see the   `appliance/common/files/timezone.txt`     file.	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             	|
| language [Required]	                      |   	**en-US**	                                                                                      |      Set the language used during the     provisioning of OS. By default, it is   set to **en-US**.	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          	|
| default_lease_time   [Required]	          |   	**86400** (24   hours),   21600 (6 hours)- 31536000 (1   Year).                                   |  Measures (in seconds) the time period an   IP   is reserved for an assigned   NIC.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          	|
| host_network_nic	[Required]	              |   	**eno3**	                                                                                      |      NIC or Ethernet card that is connected   to   the Host Network to provision OS   on bare   metal servers. By default, it   is set     to "eno3".	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        	|
| host_network_dhcp_start_range   [Required]  |    **172.19.0.100**                                                                                   | Start IP for the DHCP range used by   the  Host Network to assign  IPv4 addresses.	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           	|
| host_network_dhcp_end_range	[Required]	  |  **172.19.0.200**		                                                                              | End   IP for the DHCP range used by the  Host   Network to assign  IPv4   addresses.	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         	|
| primary_dns  [Optional]                     |                                                                                                       |     The primary DNS host IP queried by Cobbler   to provide Internet access to Compute Node   (through DHCP routing)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         	|
| secondary_dns	 [Optional]                   |                                                                                                       |       The secondary DNS host IP queried by   Cobbler to provide Internet   access to   Compute Node (through DHCP routing)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   	|
| host_mapping_file_path	[Optional]        |   		                                                                                              |        Enter the file path containing a hostmapping file with the MAC   addresses, hostnames, IP addresses, and     component   role.	A *mapping_host_file.csv*   template file is provided   [here](../../../examples/host_mapping_file_one_touch.csv). Enter the details   in the order: **MAC address,     Hostname, IP   address,   Component_role**. For example,       `10:11:12:13,server1,100.96.20.66,compute`,     `14:15:16:17,server2,100.96.22.199,manager`,       `18.19.20.21,server3,100.96.23.67,nfs_node`, and       `22.23.24.25,server4,100.96.23.75,login_node` are all valid entries.   The     Hostname should not contain the     following characters: , (comma), \. (period),   and - (hyphen). Ensure that you do   not   provide any duplicate entries in   the     file.	<br> Another   approach to filling this file maps IPs and MAC addresses based on the   provided [example](../../../examples/host_mapping_file_os_provisioning.csv)                                                                                                                                       	|
| mngmnt_network_nic	[Optional]	          |   	**eno1**	                                                                                      |      NIC or Ethernet card that is connected   to   the Management Network to   provision the   devices. By default, it   is set to     "eno1".	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               	|
| mngmnt_network_dhcp_start_range   [Optional]| **172.19.0.100**                                                                                      |      Start IP for the   DHCP range   used by the Management Network to     assign IPv4 addresses.	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            	|
| mngmnt_network_dhcp_end_range   [Optional]|    **172.19.0.200**	                                                                                  |    End IP for the   DHCP range used by the Management Network   to   assign IPv4 addresses.	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  	|
| mngmnt_mapping_file_path   [Optional]	      |   		                                                                                              | The file path containing a device   mapping file with the MAC addresses   and   respective IP addresses.	A     *mapping_device_file.csv* template file   is provided [here](../../../examples)     Enter the details   in the   order: **MAC address, IP address**. For example,   `10:11:12:13,1.2.3.4`,   `14:15:16:17,2.3.4.5`, and   `18.19.20.21,3.4.5.6` are   all valid   entries. Ensure that you do not     provide any duplicate entries in     the   file.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         	|
| ib_network_nic  [Optional]                  |  **ib0**                                                                                              |   The NIC/Ethernet card to be used when   configuring Infiniband switches. <br> This parameter is mandatory if   `ib_switch_support` is true.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                	|
| ib_network_dhcp_start_range   [Optional]    |     **172.25.0.100**                                                                                  |         The start IP for the range within which the Infiniband Switch IP is to   be configured. <br> This parameter is mandatory if `ib_switch_support`   is true.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           	|
| ib_network_dhcp_end_range	   [Optional]     | **172.25.0.200**                                                                                      |       The end IP for the range within which   the Infiniband Switch IP is to be configured. <br> This parameter is   mandatory if `ib_switch_support` is true.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               	|